"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const fs_1 = __importDefault(require("fs"));
const cli_utils_1 = require("@pnpm/cli-utils");
const config_1 = require("@pnpm/config");
const pick_1 = __importDefault(require("ramda/src/pick"));
const render_help_1 = __importDefault(require("render-help"));
const tempy_1 = __importDefault(require("tempy"));
const error_1 = require("@pnpm/error");
const writePackage_1 = require("./writePackage");
function rcOptionsTypes() {
    return (0, pick_1.default)([], config_1.types);
}
exports.rcOptionsTypes = rcOptionsTypes;
function cliOptionsTypes() {
    return { ...rcOptionsTypes(), 'edit-dir': String };
}
exports.cliOptionsTypes = cliOptionsTypes;
exports.shorthands = {
    d: '--edit-dir',
};
exports.commandNames = ['patch'];
function help() {
    return (0, render_help_1.default)({
        description: 'Prepare a package for patching',
        descriptionLists: [{
                title: 'Options',
                list: [
                    {
                        description: 'The package that needs to be modified will be extracted to this directory',
                        name: '--edit-dir',
                    },
                ],
            }],
        url: (0, cli_utils_1.docsUrl)('patch'),
        usages: ['pnpm patch <pkg name>@<version>'],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (opts.editDir && fs_1.default.existsSync(opts.editDir) && fs_1.default.readdirSync(opts.editDir).length > 0) {
        throw new error_1.PnpmError('PATCH_EDIT_DIR_EXISTS', `The target directory already exists: '${opts.editDir}'`);
    }
    const editDir = opts.editDir ?? tempy_1.default.directory();
    await (0, writePackage_1.writePackage)(params[0], editDir, opts);
    return `You can now edit the following folder: ${editDir}

Once you're done with your changes, run "pnpm patch-commit ${editDir}"`;
}
exports.handler = handler;
//# sourceMappingURL=patch.js.map